Struct amazon_sp_vendor_shipments::models::item_details::ItemDetails
source · [−]pub struct ItemDetails {
pub purchase_order_number: Option<String>,
pub lot_number: Option<String>,
pub expiry: Option<Box<Expiry>>,
pub maximum_retail_price: Option<Box<Money>>,
pub handling_code: Option<HandlingCode>,
}Expand description
ItemDetails : Item details for be provided for every item in shipment at either the item or carton or pallet level, whichever is appropriate.
Fields
purchase_order_number: Option<String>The Amazon purchase order number for the shipment being confirmed. If the items in this shipment belong to multiple purchase order numbers that are in particular carton or pallet within the shipment, then provide the purchaseOrderNumber at the appropriate carton or pallet level. Formatting Notes: 8-character alpha-numeric code.
lot_number: Option<String>The batch or lot number associates an item with information the manufacturer considers relevant for traceability of the trade item to which the Element String is applied. The data may refer to the trade item itself or to items contained. This field is mandatory for all perishable items.
expiry: Option<Box<Expiry>>maximum_retail_price: Option<Box<Money>>handling_code: Option<HandlingCode>Identification of the instructions on how specified item/carton/pallet should be handled.
Implementations
sourceimpl ItemDetails
impl ItemDetails
sourcepub fn new() -> ItemDetails
pub fn new() -> ItemDetails
Item details for be provided for every item in shipment at either the item or carton or pallet level, whichever is appropriate.